
/**
 * Bank class managing bank accounts.
 * TO DO:  eliminate the redundancy in the
 * deposit, withdraw and getBalance methods.
 * Use a findAccount() method.
 * 
 * @author JP Vergara
 * @version 1.0
 */

public class Bank
{
   private BankAccount[] accounts;
   public static final int MAX = 100; // size of the array
   private int numAccounts; // actual number of bank accounts
   
   /*
    * Constructor for Bank.  Create the array and set count to 0
    * 
    */
   public Bank()
   {
       accounts = new BankAccount[MAX];
       numAccounts = 0;
   }

   /*
    * Open a bank account; create a BankAccount object with the
    * given details (account number and initial balance),
    * and include it in the array
    * 
    * @param name           name
    * @param initBal        initial balance
    * 
    */

   public void openAccount( String name, double initBal )
   {
       BankAccount temp = new BankAccount( name, initBal );
       accounts[numAccounts] = temp; // numAccounts points to next available array slot
       numAccounts++;
   }

   /*
    * Deposit some amount to the account with the given account name.
    * If account does not exist, do nothing
    * 
    * @param name           name
    * @param amount         amount to deposit
    * 
    */
   
   public void deposit( String name, double amount )
   {
       BankAccount temp = null;
       for( int i = 0; i < numAccounts; i++ )
       {
           if ( accounts[i].getAcctName().equals(name) )
           // found a match
           {
               temp = accounts[i];
               // break; // uncomment this line to fall out of loop immediately
           }
       }
       if ( temp != null )
       {
           temp.deposit( amount );
       }
   }

   /*
    * Withdraw some amount from the account with the given account name.
    * If account does not exist, do nothing
    * 
    * @param name           name
    * @param amount         amount to withdraw
    * 
    */
   
   public void withdraw( String name, double amount )
   {
       BankAccount temp = null;
       for( int i = 0; i < numAccounts; i++ )
       {
           if ( accounts[i].getAcctName().equals(name) )
           // found a match
           {
               temp = accounts[i];
               // break; // uncomment this line to fall out of loop immediately
           }
       }
       if ( temp != null )
       {
           temp.withdraw( amount );
       }
   }

   /*
    * Return the balance of the account with the given account name.
    * If account does not exist, return 0
    * 
    * @param name           name
    * @return balance
    * 
    */

   public double getBalance( String name )
   {
       BankAccount temp = null;
       for( int i = 0; i < numAccounts; i++ )
       {
           if ( accounts[i].getAcctName().equals(name) )
           // found a match
           {
               temp = accounts[i];
               // break; // uncomment this line to fall out of loop immediately
           }
       }
       if ( temp == null )
       {
           return 0;
       }
       else
       {
           return temp.getBalance();
       }
   }

}
